% drawPend.m
%
% Matlab script that draws a pendulum's position at a given time 
%
% Dynamic Programming and Optimal Control
% Fall 2009
% Exercise in class
%
% Input: time value and state [theta, thetadot], theta measured from 
%        hanging down, counterclockwise
%
%
% --
% ETH Zurich
% Institute for Dynamic Systems and Control
% Angela Schllig
% aschoellig@ethz.ch
%
% --
% Revision history
% [15.12.09, AS]    first version
%
%  

function status = drawPend(t,x,flag)
  % written so that it can be used as an output function for ode
  persistent hFig base a1 ac1 raarm;

  if (isempty(hFig))
    hFig = figure(25);
    set(hFig,'DoubleBuffer', 'on');

    a1 = 0.75;  ac1 = 0.415;
    av = pi*[0:.05:1];
    rb = .03; hb=.07;
    aw = .01;
    base = rb*[1 cos(av) -1 1; -hb/rb sin(av) -hb/rb -hb/rb]';
    arm = [aw*cos(av-pi/2) -a1+aw*cos(av+pi/2)
      aw*sin(av-pi/2) aw*sin(av+pi/2)]';
    raarm = [(arm(:,1).^2+arm(:,2).^2).^.5, atan2(arm(:,2),arm(:,1))];
  end
  
  if (strcmp(flag,'done'))
    return;
  end

  figure(hFig); cla; hold on; view(0,90);
  patch(base(:,1), base(:,2),1+0*base(:,1),'b','FaceColor',[.3 .6 .4])
  patch(raarm(:,1).*sin(raarm(:,2)+x(1)-pi),...
    -raarm(:,1).*cos(raarm(:,2)+x(1)-pi), ...
    0*raarm(:,1),'r','FaceColor',[.9 .1 0])
  plot3(ac1*sin(x(1)), -ac1*cos(x(1)),1, 'ko',...
    'MarkerSize',10,'MarkerFaceColor','b')
  plot3(0,0,1.5,'k.')
  title(['t = ', num2str(t(1),'%.2f') ' sec']);
  set(gca,'XTick',[],'YTick',[])

  axis image; axis([-1.0 1.0 -1.0 1.0]);
  drawnow;

  status = 0;
end